@@ -9,7 +9,7 @@ use XML::Simple;
 use warnings;
 use strict;
 
-our $VERSION = '2.403'; # TRIAL VERSION
+our $VERSION = '2.405'; # TRIAL VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 # ADMIN OPTS - http://www.vmware.com/support/vcd/doc/rest-api-doc-1.5-html/landing-admin_operations.html
@@ -161,7 +161,7 @@ sub _xml_response {
 sub _parse_xml {
     my $self = shift @_;
     my $xml  = shift @_;
-    my $data = XMLin( $xml, ForceArray => 1 );
+    my $data = XMLin( $xml, ForceArray => 1, KeyAttr => [qw(id )] );
     return $data;
 }
 
@@ -1035,7 +1035,7 @@ VMware::API::vCloud - VMware vCloud Director
 
 =head1 VERSION
 
-version 2.403
+version 2.405
 
 =head1 SYNOPSIS
 
@@ -1065,6 +1065,15 @@ perform a dangerous action, do so in an eval block and evaluate $@.
 
 VMware::API::vCloud - The VMware vCloud API
 
+=head1 BROKEN COMPATIBILITY
+
+Versions of this module up to and including version C<2.404> used the
+L<XML::Simple> default XML to hash folding mechanism which would take the first
+one of C<name>, C<key> and C<id> to use at the hash key attribute.  This caused
+problems where multiple items with the same name could occur.  This version
+only uses the C<id> attribute to fold into hashes.  This means that some code
+will need adjusting to deal with the changed hash folding.
+
 =head1 OBJECT METHODS
 
 These methods are not API calls. They represent the methods that create this
